@@ -9,9 +9,14 @@ from .JSONType import JSONType
 class KernelVariable(BaseModel):
     name: str
     type: Optional[str]
+    abbreviated: Optional[bool] = False
     value: JSONType
     summary: Optional[str]
 
 
+class KernelVariableWrapper(BaseWrapper):
+    single_var: KernelVariable
+
+
 class KernelVariablesWrapper(BaseWrapper):
     vars: List[KernelVariable]
