@@ -63,6 +63,6 @@ async def kernel_is_alive(uuid: str, status_code=status.HTTP_204_NO_CONTENT):
 @router.get(
     "/idle", status_code=status.HTTP_200_OK, response_model=KernelsIdle
 )
-def idle_status():
+async def idle_status():
     "Check if all kernels are idle"
     return KernelsIdle(idle=manager.is_idle(), last_idle=manager.last_idle)
