@@ -14,6 +14,7 @@ from fastapi import (
     Response,
     WebSocket,
     status,
+    Query,
 )
 from fastapi.encoders import jsonable_encoder
 from fastapi.logger import logger
@@ -392,7 +393,8 @@ async def patch_and_execute_notebook_cell(
     msg_id = await manager.execute(uuid, cell_uuid)
     schedule_notebook_save(background_tasks, uuid=uuid)
     return CellKernelMessageWrapper(
-        cell=cell, kernel_message=KernelMessage(message_id=msg_id),
+        cell=cell,
+        kernel_message=KernelMessage(message_id=msg_id),
     )
 
 
@@ -411,7 +413,9 @@ async def change_working_directory(uuid: UUID, directory: str):
 
 
 def format_file_path(
-    directory: Optional[str], filename: str, allow_exists: bool = False,
+    directory: Optional[str],
+    filename: str,
+    allow_exists: bool = False,
 ) -> Dict[str, str]:
     """
     Gets absolute path for file, filename with extension, checks that directory
@@ -454,7 +458,7 @@ async def upload_notebook(
     body = await request.body()
     path_info = format_file_path(directory, filename)
     try:
-        manager.upload_notebook(
+        await manager.upload_notebook(
             body, path_info["directory"], path_info["filename"]
         )
     except (jsonschema.exceptions.ValidationError, AttributeError) as e:
@@ -523,7 +527,9 @@ async def open_notebook(
         raise HTTPException(status_code=404, detail=f"File not found")
     try:
         nb_uuid = await manager.open_notebook(
-            abs_path, kspec_name=kspec_name, working_directory=working_directory
+            abs_path,
+            kspec_name=kspec_name,
+            working_directory=working_directory,
         )
 
         nb = manager.get_notebook_node(nb_uuid)
@@ -531,7 +537,7 @@ async def open_notebook(
 
     except (jsonschema.exceptions.ValidationError, AttributeError) as e:
         raise HTTPException(400, f"Failed to parse notebook: {type(e)} {e}")
-    
+
 
 @router.post(
     "/create",
@@ -569,7 +575,7 @@ async def save_notebook_as(
     overwrite: bool = False,
 ):
     path_info = format_file_path(directory, filename, overwrite)
-    manager.save_notebook_as(
+    await manager.save_notebook_as(
         uuid, path_info["directory"], path_info["filename"]
     )
     return NotebookPath(path=path_info["absolute_path"])
@@ -586,10 +592,24 @@ async def rename_notebook(
     filename: str,
     directory: Optional[str] = None,
     overwrite: bool = False,
+    just_metadata: bool = Query(
+        False,
+        description="Just update the in-memory"
+        " notebook's metadata, dont save or delete any files. Used by the local "
+        "environment on Callisto Mac/iPad, where file operations are handled in "
+        "swift"
+    ),
 ):
-    path_info = format_file_path(directory, filename, overwrite)
-    manager.save_notebook_as(
-        uuid, path_info["directory"], path_info["filename"], delete_old=True
+    """
+    Rename a notebook, save it, and update it's name and path in its metadata
+    """
+    path_info = format_file_path(directory, filename, overwrite or just_metadata)
+    await manager.save_notebook_as(
+        uuid,
+        path_info["directory"],
+        path_info["filename"],
+        delete_old=not just_metadata,
+        just_metadata=just_metadata
     )
     return NotebookPath(path=path_info["absolute_path"])
 
@@ -868,7 +888,9 @@ async def websocket_cells(
     signal(KERNEL_RESTARTED).connect(receive_kernel_restarted)
 
     async def receive_kernel_interrupted(
-        sender: Any, notebook_id: UUID, **kwargs,
+        sender: Any,
+        notebook_id: UUID,
+        **kwargs,
     ):
         logger.debug("receiving KERNEL_INTERRUPTED")
         if notebook_id == uuid:
