@@ -17,6 +17,11 @@ class KernelListener:
         self.client = client
         self.kernel_id = kernel_id
         self.should_listen = True
+        # Strong reference to the asyncio task running this listener,
+        # set it when you create the task so it doesn't get garbage collected.
+        # see the docs:
+        # https://docs.python.org/3/library/asyncio-task.html#asyncio.create_task
+        self.asyncio_task = None
         self.iopub_signal = signal(IOPUB_CHANNEL)
         self.shell_signal = signal(SHELL_CHANNEL)
         self.stdin_signal = signal(STDIN_CHANNEL)
