@@ -11,16 +11,20 @@ from .kernel_listener import KernelListener
 
 try:
     from nb_conda_kernels import CondaKernelSpecManager as KernelSpecManager
+
     logger.debug("Successfully loaded nb_conda_kernels.")
 except ImportError as e:
     from jupyter_client.kernelspec import KernelSpecManager
+
     logger.debug(f"nb_conda_kernels disabled.  Failed to import - {e}")
 
 
 class KernelManager:
     def __init__(self):
         self._specManager = KernelSpecManager()
-        self._kmanager = AsyncMultiKernelManager(kernel_spec_manager=self._specManager)
+        self._kmanager = AsyncMultiKernelManager(
+            kernel_spec_manager=self._specManager
+        )
         self._kmanager.connection_dir = jupyter_runtime_dir()
         if not os.path.exists(self._kmanager.connection_dir):
             os.makedirs(
@@ -78,7 +82,7 @@ class KernelManager:
         # start the event listener
         listener = KernelListener(client, uuid)
         self.listeners[uuid] = listener
-        asyncio.create_task(listener.listen())
+        listener.asyncio_task = asyncio.create_task(listener.listen())
 
     async def execute(
         self,
@@ -89,7 +93,9 @@ class KernelManager:
     ):
         client = self.clients[uuid]
         msg_id = client.execute(
-            code, silent=silent, store_history=store_history,
+            code,
+            silent=silent,
+            store_history=store_history,
         )
         return msg_id
 
