@@ -10,6 +10,7 @@ from uuid import UUID
 import nbformat  # type: ignore
 from asyncblink import signal  # type: ignore
 from fastapi.logger import logger
+from fastapi.concurrency import run_in_threadpool
 
 from jupyter_d1.commands import execute_d1_command
 from jupyter_d1.dav import dav_manager
@@ -171,7 +172,7 @@ class NotebookManager:
             working_directory=working_directory,
         )
 
-    def save_notebook(
+    async def save_notebook(
         self,
         notebook: Optional[NotebookNode] = None,
         uuid: Optional[UUID] = None,
@@ -182,33 +183,42 @@ class NotebookManager:
         if nb is None:
             raise NBMException(NBMErrorCode.notebook_not_found, uuid)
         path = nb.metadata.jupyter_d1.path
-        nbformat.write(nb, path, default=D1Encoder().default)
+        await run_in_threadpool(
+            nbformat.write, nb, path, default=D1Encoder().default
+        )
 
-    def save_notebook_as(
+    async def save_notebook_as(
         self,
         uuid: UUID,
         directory: str,
         filename: str,
         delete_old: bool = False,
+        just_metadata: bool = False,
     ):
         """
         Change save location of the notebook. If delete_old is set,
         the old path of the notebook is deleted (used for renaming).
+        If just_metadata is True, only update the in-memory notebook's
+        metadata.
 
         This method does not check if the path already exists and
-        will overwrite it.
+        will overwrite it (unless just_metadata is True).
         """
         nb = self.notebooks[uuid]
         if nb is None:
             raise NBMException(NBMErrorCode.notebook_not_found, uuid)
         old_path = nb.node.metadata.jupyter_d1.path
         self.validator.validate(
-            nb.node, directory, filename,
+            nb.node,
+            directory,
+            filename,
         )
-        self.save_notebook(nb.node)
 
-        if delete_old:
-            os.remove(old_path)
+        if not just_metadata:
+            await self.save_notebook(nb.node)
+
+            if delete_old:
+                os.remove(old_path)
 
         signal(METADATA_UPDATE).send(
             notebook_id=uuid, metadata=nb.node.metadata
@@ -216,7 +226,7 @@ class NotebookManager:
 
         return nb.node.metadata.jupyter_d1.path
 
-    def upload_notebook(
+    async def upload_notebook(
         self, notebook_data: bytes, directory: str, filename: str
     ):
         nb = nbformat.reads(
@@ -225,7 +235,7 @@ class NotebookManager:
         self.validator.validate(
             nb, directory, filename, new_notebook_uuid=True
         )
-        self.save_notebook(nb)
+        await self.save_notebook(nb)
 
     async def delete_notebooks(self):
         await self.kmanager.shutdown_all()
@@ -357,7 +367,7 @@ class NotebookManager:
             autosave=autosave,
         )
         if autosave:
-            self.save_notebook(notebook_node)
+            await self.save_notebook(notebook_node)
 
         signal(CELL_UPDATE).send(
             cells=notebook_node.cells, notebook_id=nb_uuid
@@ -396,6 +406,7 @@ class NotebookManager:
             CommandType.CELL_EXECUTION,
             uuid,
             cell_id=cell.metadata.jupyter_d1.uuid,
+            has_run=False,
         )
         self.post_execute_request_msg(notebook_id, cell_id, msg_id)
         return msg_id
@@ -406,7 +417,9 @@ class NotebookManager:
         # Repeat the execution request out to any client listening on the
         # websocket so it can keep track of requests from other clients
         signal(CELL_EXECUTION_REQUEST).send(
-            notebook_id=notebook_id, cell_id=cell_id, msg_id=msg_id,
+            notebook_id=notebook_id,
+            cell_id=cell_id,
+            msg_id=msg_id,
         )
 
     async def execute_scratch(self, notebook_id: UUID, code: str):
@@ -443,7 +456,9 @@ class NotebookManager:
 
     async def interrupt_kernel(self, notebook_id: UUID):
         await self.kmanager.interrupt_kernel(notebook_id)
-        signal(KERNEL_INTERRUPTED).send(notebook_id=notebook_id,)
+        signal(KERNEL_INTERRUPTED).send(
+            notebook_id=notebook_id,
+        )
 
     async def perform_restart(self, notebook_id: UUID):
         await self.kmanager.restart_kernel(notebook_id)
@@ -454,6 +469,7 @@ class NotebookManager:
     async def restart_kernel(
         self, notebook_id: UUID, clear_output: bool = False
     ):
+        notebook = self.get_notebook(notebook_id)
         await self.perform_restart(notebook_id)
         notebook = self.get_notebook(notebook_id)
         for cell in notebook.node.cells:
@@ -502,6 +518,7 @@ class NotebookManager:
                     CommandType.CELL_EXECUTION,
                     uuid,
                     cell_id=cell.metadata.jupyter_d1.uuid,
+                    has_run=False,
                 )
                 self.post_execute_request_msg(
                     notebook_id, cell.metadata.jupyter_d1.uuid, msg_id
@@ -956,7 +973,9 @@ class NotebookManager:
         elif msg_type == "execute_input":
             if command.type == CommandType.CELL_EXECUTION:
                 signal(CELL_EXECUTION_INPUT).send(
-                    notebook_id=nb_id, parent_id=parent_id, content=content,
+                    notebook_id=nb_id,
+                    parent_id=parent_id,
+                    content=content,
                 )
         elif (
             msg_type == "complete_reply"
@@ -1048,13 +1067,22 @@ class NotebookManager:
             if command.type == CommandType.CELL_EXECUTION:
                 cell.metadata.jupyter_d1["execution_state"] = execution_state
                 logger.debug("nb_manager posting CELL_UPDATE - status")
-                if execution_state == ExecutionState.busy:
+                if (
+                    execution_state == ExecutionState.busy
+                    and not command.extras["has_run"]
+                ):
                     cell.outputs = []
+                    # The has_run flag is used so we only reset the cell
+                    # output the first time this cell is "busy" as a result of
+                    # this particular Command (another "busy" status and a
+                    # "shutdown_reply" message are emitted on behalf of this
+                    # Command on kernel restart)
+                    command.extras["has_run"] = True
                 signal(CELL_UPDATE).send(cells=[cell], notebook_id=nb_id)
                 if execution_state == ExecutionState.idle:
                     notebook = self.notebooks.get(nb_id, None)
                     if notebook is not None and notebook.autosave:
-                        self.save_notebook(uuid=nb_id)
+                        await self.save_notebook(uuid=nb_id)
             elif command.type == CommandType.SCRATCH_EXECUTION:
                 logger.debug("nb_manager posting SCRATCH_UPDATE - status")
                 command.extras["execution_state"] = ExecutionState(
@@ -1107,7 +1135,7 @@ class NotebookManager:
                             )
                             notebook = self.notebooks.get(nb_id, None)
                             if notebook is not None and notebook.autosave:
-                                self.save_notebook(uuid=nb_id)
+                                await self.save_notebook(uuid=nb_id)
                             self.change_dav_workdir(nb_id, resolved_workdir)
                             signal(METADATA_UPDATE).send(
                                 notebook_id=nb_id, metadata=metadata
