@@ -105,22 +105,26 @@ class StatsManager:
             timestamp=datetime.now(),
             cpu=CPUStats(percent=cpu_usage, load_percent=cpu_load_percent),
             disk=DiskStats(
-                free=disk_usage.free,
-                percent=disk_usage.percent,
-                total=disk_usage.total,
+                free=getattr(disk_usage, "free", 0),
+                percent=getattr(disk_usage, "percent", 0),
+                total=getattr(disk_usage, "total", 0),
             ),
             memory=MemoryStats(
-                available=memory_usage.available, total=memory_usage.total
+                available=getattr(memory_usage, "available", 0),
+                total=getattr(memory_usage, "total", 0),
             ),
             gpu=gpu_stat_list,
         )
         self.put(server_stats)
         return server_stats
 
-    def dispatch_server_stats(self):
+    async def dispatch_server_stats(self):
         server_stats = None
         try:
-            server_stats = self.collect_server_stats()
+            loop = asyncio.get_event_loop()
+            server_stats = await loop.run_in_executor(
+                None, self.collect_server_stats
+            )
         except Exception:
             pass
         if server_stats is not None:
@@ -128,5 +132,5 @@ class StatsManager:
 
     async def server_stats_periodic(self):
         while True:
-            self.dispatch_server_stats()
+            await self.dispatch_server_stats()
             await asyncio.sleep(settings.SERVER_STATS_POLLING_INTERVAL)
