@@ -9,6 +9,7 @@ import pytest  # type: ignore
 from async_asgi_testclient import (
     TestClient as WebSocketTestClient,  # type: ignore
 )
+import pytest_asyncio
 from fastapi.logger import logger
 from fastapi.testclient import TestClient
 
@@ -92,7 +93,7 @@ def clear_notebook_directory_2() -> Generator:
             print("Failed to delete %s. Reason: %s" % (file_path, e))
 
 
-@pytest.fixture()
+@pytest_asyncio.fixture
 async def websocket_client() -> AsyncGenerator:
     async with WebSocketTestClient(app) as c:
         yield c
