@@ -30,7 +30,8 @@ is_mac = platform.system().startswith("Darwin")
 
 class TestDav:
     def test_dav_auth(
-        self, client: TestClient,
+        self,
+        client: TestClient,
     ):
         response = client.get("/dav")
         assert response.status_code == 401
@@ -135,7 +136,7 @@ class TestDav:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        If notebook is in subdirectory of d1's working directory, 
+        If notebook is in subdirectory of d1's working directory,
         dav should work regardless of whether the notebook is open.
         """
         pathlib.Path(f"{settings.ROOT_DIR}/some_nbs").mkdir(exist_ok=True)
@@ -254,7 +255,6 @@ class TestWatchdogWebSocket:
         async with websocket_client.websocket_connect(
             f"/server/ws", headers=superuser_token_headers
         ) as websocket:
-            # assert False
             await self.create_dir(websocket, ututils)
 
     async def test_create_file(
@@ -432,7 +432,8 @@ class TestWatchdogWebSocket:
 
             # Upload notebook, workdir same as root dir
             uuid = await upload_notebook(
-                websocket_client, superuser_token_headers,
+                websocket_client,
+                superuser_token_headers,
             )
 
             # Change nb workdir
@@ -560,7 +561,8 @@ class TestWatchdogWebSocket:
 
             # Upload notebook, workdir same as root dir
             uuid = await upload_notebook(
-                websocket_client, superuser_token_headers,
+                websocket_client,
+                superuser_token_headers,
             )
             uuid2 = await upload_notebook(
                 websocket_client,
