@@ -22,7 +22,10 @@ def test_get_access_token(client: TestClient) -> None:
 def test_use_access_token(
     client: TestClient, superuser_token_headers: Dict[str, str]
 ) -> None:
-    r = client.post(f"/login/test-token", headers=superuser_token_headers,)
+    r = client.post(
+        f"/login/test-token",
+        headers=superuser_token_headers,
+    )
     result = r.json()["permission"]
     assert r.status_code == 200
     assert result["id"] == -1
