@@ -7,6 +7,7 @@ import pytest  # type: ignore
 from fastapi.testclient import TestClient
 
 from jupyter_d1.settings import settings
+from .utils import msg_id_lengths
 
 
 def upload_notebook(
@@ -911,14 +912,14 @@ class TestNotebook:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        Working directory should default to root dir, 
+        Working directory should default to root dir,
         notebook should not be saved on disk.
         """
         nb_filename = f"jupyter_d1/tests/notebooks/simple.ipynb"
         nb_json = open(nb_filename).read()
         response = client.post(
             "/notebooks/upload_and_open",
-            params={"filename": "name.ipynb", "autosave": False},
+            params={"filename": "name.ipynb", "autosave": "False"},
             data=nb_json,
             headers=superuser_token_headers,
         )
@@ -969,7 +970,7 @@ class TestNotebook:
             f.write(nb_json)
         response = client.post(
             "/notebooks/upload_and_open",
-            params={"filename": "name.ipynb", "autosave": False},
+            params={"filename": "name.ipynb", "autosave": "False"},
             data=nb_json,
             headers=superuser_token_headers,
         )
@@ -1000,7 +1001,7 @@ class TestNotebook:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        Working directory should be set to specified directory, 
+        Working directory should be set to specified directory,
         notebook should not be saved on disk.
         """
         nb_filename = f"jupyter_d1/tests/notebooks/simple.ipynb"
@@ -1009,7 +1010,7 @@ class TestNotebook:
             "/notebooks/upload_and_open",
             params={
                 "filename": "name.ipynb",
-                "autosave": False,
+                "autosave": "False",
                 "working_directory": f"{os.getcwd()}/jupyter_d1"
                 "/tests/notebooks",
             },
@@ -1047,7 +1048,7 @@ class TestNotebook:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        Working directory should default to root dir, 
+        Working directory should default to root dir,
         notebook should be saved on disk.
         """
         nb_filename = f"jupyter_d1/tests/notebooks/simple.ipynb"
@@ -1085,7 +1086,7 @@ class TestNotebook:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        Working directory should default to root dir, 
+        Working directory should default to root dir,
         notebook should be saved on disk.
         """
         try:
@@ -1181,7 +1182,7 @@ class TestNotebook:
         self, client: TestClient, superuser_token_headers: Dict[str, str]
     ):
         """
-        Working directory should be set to provided working dir, 
+        Working directory should be set to provided working dir,
         notebook should be saved on disk.
         """
         try:
@@ -1273,7 +1274,7 @@ class TestNotebook:
         nb_json = open(nb_filename).read()
         response = client.post(
             "/notebooks/upload_and_open",
-            params={"autosave": False},
+            params={"autosave": "False"},
             data=nb_json,
             headers=superuser_token_headers,
         )
@@ -1291,7 +1292,7 @@ class TestNotebook:
 
         response = client.post(
             "/notebooks/upload_and_open",
-            params={"autosave": False, "working_directory": "/tmp"},
+            params={"autosave": "False", "working_directory": "/tmp"},
             data=json.dumps(resp_json["notebook"]),
             headers=superuser_token_headers,
         )
@@ -1324,13 +1325,17 @@ class TestNotebook:
         """
         response = client.post(
             "/notebooks/upload",
-            params={"filename": "name.ipynb", "autosave": False},
+            params={"filename": "name.ipynb", "autosave": "False"},
             data="{}",
             headers=superuser_token_headers,
         )
         assert response.status_code == 400
-        assert response.json()["detail"] == \
-            "Failed to parse notebook: <class 'AttributeError'> cells"
+        assert (
+            response.json()["detail"] == "Failed to parse notebook: "
+            "<class 'jsonschema.exceptions.ValidationError'> Notebook could"
+            " not be converted from version 1 to version 2 because it's"
+            " missing a key: cells"
+        )
 
     def test_open_invalid_notebook(
         self, client: TestClient, superuser_token_headers: Dict[str, str]
@@ -1348,8 +1353,12 @@ class TestNotebook:
             headers=superuser_token_headers,
         )
         assert response.status_code == 400
-        assert response.json()["detail"] == \
-            "Failed to parse notebook: <class 'AttributeError'> cells"
+        assert (
+            response.json()["detail"] == "Failed to parse notebook: "
+            "<class 'jsonschema.exceptions.ValidationError'> Notebook could"
+            " not be converted from version 1 to version 2 because it's"
+            " missing a key: cells"
+        )
 
     def test_upload_and_open_invalid_notebook(
         self, client: TestClient, superuser_token_headers: Dict[str, str]
@@ -1359,13 +1368,17 @@ class TestNotebook:
         """
         response = client.post(
             "/notebooks/upload_and_open",
-            params={"filename": "name.ipynb", "autosave": False},
+            params={"filename": "name.ipynb", "autosave": "False"},
             data="{}",
             headers=superuser_token_headers,
         )
         assert response.status_code == 400
-        assert response.json()["detail"] == \
-            "Failed to parse notebook: <class 'AttributeError'> cells"
+        assert (
+            response.json()["detail"] == "Failed to parse notebook: "
+            "<class 'jsonschema.exceptions.ValidationError'> Notebook could"
+            " not be converted from version 1 to version 2 because it's"
+            " missing a key: cells"
+        )
 
 
 @pytest.mark.usefixtures("clear_notebooks", "clear_notebook_directory")
@@ -1541,7 +1554,7 @@ class TestNotebookPermissions:
         uuid = response.json()["cell"]["metadata"]["jupyter_d1"]["uuid"]
         assert len(uuid) == 36
         message_id = response.json()["kernel_message"]["message_id"]
-        assert len(message_id) == 35
+        assert len(message_id) in msg_id_lengths
 
     def test_create_cell(
         self,
