@@ -6,6 +6,7 @@ from async_asgi_testclient import (
     TestClient as WebSocketTestClient,  # type: ignore
 )
 from fastapi.testclient import TestClient
+import pytest_asyncio
 from pytest_mock import MockFixture  # type: ignore
 
 from .utils import wait_for_event
@@ -82,7 +83,7 @@ def test_rclone_post_data(
     )
 
 
-@pytest.fixture()
+@pytest_asyncio.fixture()
 async def superuser_token_headers(
     websocket_client: WebSocketTestClient,
 ) -> Dict[str, str]:
