@@ -3,7 +3,8 @@ from datetime import datetime
 from typing import AsyncGenerator, Dict
 
 import pytest  # type: ignore
-from async_asgi_testclient import TestClient  # type: ignore
+from async_asgi_testclient import TestClient
+import pytest_asyncio  # type: ignore
 from pytest_mock import MockFixture  # type: ignore
 
 from jupyter_d1 import app
@@ -19,13 +20,13 @@ from jupyter_d1.settings import settings
 from .utils import wait_for_event
 
 
-@pytest.fixture()
+@pytest_asyncio.fixture()
 async def client() -> AsyncGenerator:
     async with TestClient(app) as c:
         yield c
 
 
-@pytest.fixture()
+@pytest_asyncio.fixture()
 async def superuser_token_headers(client: TestClient) -> Dict[str, str]:
     r = await client.get(
         "/login/access-token", headers={"Authorization": "test9token_4"}
@@ -38,7 +39,9 @@ async def superuser_token_headers(client: TestClient) -> Dict[str, str]:
 class TestStats:
     @pytest.mark.asyncio
     async def test_get_stats(
-        self, client: TestClient, superuser_token_headers: Dict[str, str],
+        self,
+        client: TestClient,
+        superuser_token_headers: Dict[str, str],
     ):
         await asyncio.sleep(1)
         response = await client.get(
@@ -58,7 +61,9 @@ class TestStats:
 
     @pytest.mark.asyncio
     async def test_get_latest_stats(
-        self, client: TestClient, superuser_token_headers: Dict[str, str],
+        self,
+        client: TestClient,
+        superuser_token_headers: Dict[str, str],
     ):
         await asyncio.sleep(1)
         response = await client.get(
@@ -125,7 +130,9 @@ class TestStats:
 
     @pytest.mark.asyncio
     async def test_get_environment(
-        self, client: TestClient, superuser_token_headers: Dict[str, str],
+        self,
+        client: TestClient,
+        superuser_token_headers: Dict[str, str],
     ):
         await asyncio.sleep(1)
         response = await client.get(
@@ -162,7 +169,9 @@ class TestStats:
 
     @pytest.mark.asyncio
     async def test_get_version(
-        self, client: TestClient, superuser_token_headers: Dict[str, str],
+        self,
+        client: TestClient,
+        superuser_token_headers: Dict[str, str],
     ):
         response = await client.get(
             f"/server/version", headers=superuser_token_headers
